@@ -205,11 +205,12 @@ def _plate_384_random_index_384(plate_info, barcode_table, i5_reverse_comp=False
     """
     records = []
 
-    # check plate_info primer compatibility
-    for primer_name, n_primer in plate_info['primer_name'].value_counts().iteritems():
-        if n_primer > 1:
-            raise ValueError(f'{primer_name} have {n_primer} multiplex_group in the table, that is impossible.')
-
+    # this is now possible because we may used the same PCR index for the same plate
+    # # check plate_info primer compatibility
+    # for primer_name, n_primer in plate_info['primer_name'].value_counts().iteritems():
+    #     if n_primer > 1:
+    #         raise ValueError(f'{primer_name} have {n_primer} multiplex_group in the table, that is impossible.')
+    
     for _, row in plate_info.iterrows():
         plate = row['plate_id']
         # remove all the '-' with '_' in plate names
